@@ -10,6 +10,7 @@
 
 #include "oxygenhelper.h"
 
+#include <KColorScheme>
 #include <KColorUtils>
 #include <KWindowSystem>
 
@@ -19,7 +20,11 @@
 #include <math.h>
 
 #if OXYGEN_HAVE_X11
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QX11Info>
+#else
+#include <private/qtx11extras_p.h>
+#endif
 #endif
 
 namespace Oxygen
